==> go.php?file=PhoenixStyle1.558.zip: PhoenixStyleMod_Firelands/Localization/localization-deDE.lua <==
﻿if GetLocale() == "deDE" then


function psfirellocale()

	psfirebabah = "explodierte"
	psfirebabah2 = "Eigenbeschuss mit |s4id98620,100215,100216,100217|id an Spielern"
	psfirebaleroccrystal = "Kristall"
	psfireby = "von"
	psfireconsumeadd = "Aschenweberdrohne bekam |sid100634|id"
	psfiredamshared = "explosion geteilt zwischen"
	psfiredeadrag = "GESTORBEN"
	psfirediddamageto = "Machte schaden auf"
	psfirediedfrom = "starb von"
	psfireended = "beendet"
	psfirefixate1 = "letzte erledigt vor %s  sek"
	psfirehealedhimself = "geheilt"
	psfireintershanox = "Unterbrochen von"
	psfirekilledplayer = "tötete Spieler!"
	psfirekilledplayers = "tötete %s Spieler!"
	psfireldamagefrom = "Schaden von"
	psfirelgot = "bekam"
	psfirelgotinf = "bekamen"
	psfirelgotinm = "bekamen"
	psfirelgotm = "bekam"
	psfirellastmoduleloadtxt = "Feuerlande"
	psfireltotal = "gesamt"
	psfirelwhogot = "Bekamen"
	psfiremajodamag1 = "Jeder bekam schaden!"
	psfiremajodamag2 = "|s4id98474,100212,100213,100214|id kein schaden auf"
	psfiremajodamag3 = "kein schaden auf"
	psfiremajogotdmg1 = "|s4id98474,100212,100213,100214|id bekamen schaden"
	psfiremajogotdmg2 = "Nur eine Person bekam schaden"
	psfiremajogotdmg3 = "bekamen schaden"
	psfiremaybeexcessd = "möglicher übermaß an schaden auf"
	psfireno = "NEIN"
	psfirenofistsec2 = "nicht die ersten 2 sek"
	psfirenotsure = "nicht sicher"
	psfireragnaknock1 = "Übermaß an Schaden von |sid100115|id. AddOn konnte nicht herrausfinden wer näher als 6 yards war"
	psfireragnaknock2 = "bekam %s anstatt von"
	psfireragnaknock3 = "Näher als 6 yards"
	psfireshanaddopt1 = "AoE vom Speer"
	psfireshanaddopt2 = "schaden vom Speer"
	psfireshanaddopt3 = "übermaß"
	psfirestaks = "Stapel"
	psfiretauntseff = "erfolgreiche spots auf Aschenweberspinner"
	psfiretauntseff2 = "Spots auf Aschenweberspinner"
	psfiretimes = "mal" -- Needs review
	psfiretrapragna1 = "Zu nahe Spieler (bis zu 8 yards):"
	psfiretrapragna2 = "Niemand wurde im umkreis von  8 yards gefunden"
	psfiretxtopt512 = "|tip2 Wie viele Heilung der Boss von |sid99332|id erhielt"
	psfiretxtopt515 = "|tip1 Wenn jemand anders schaden von |sid100833|id bekommt - zeige wer das Add getankt hat usw. (|cffff0000hero|r)"
	psfiretxtopt516 = "|tip1 Wenn mehr als einer schaden von |sid100838|id bekommt - zeige Chatinfo (|cffff0000hero|r)"
	psfiretxtopt517 = "|tip2 Wer Spot auf Aschenweberspinner benutzte (mehr info im 'im Kampf info' Modul)"
	psfiretxtopt518 = "|tip2 Wie oft Aschenweberdrohne |sid100634|id bekam"
	psfiretxtopt522 = "|tip2 Wie oft Flüssiges Obsidian |sid99875|id zauberte"
	psfiretxtopt533 = "|tip1 Berichte wenn NICHT ein Spieler |sid100359|id bekam"
	psfiretxtopt544 = "|tip2 Wer |sid99947|id unterbrach indem er schaden aufs Add gemacht hat (gesamt)"
	psfiretxtopt551 = "|tip1 wenn ein Spieler vom Kristall mit |sid99403|id getötet wurde - zeige info (wer es auffrischte - |cffff0000hero|r)"
	psfiretxtopt552 = "|tip1 wenn ein Spieler von |sid99353|id getötet wurde mit |sid99403|id - zeige info (wer es auffrischte - |cffff0000hero|r)"
	psfiretxtopt553 = "|tip1 Zeige wer |sid99516|id hatte wenn eine explosion stattgefunden hat (|cffff0000hero|r)"
	psfiretxtopt561 = "|tip1 Wer schaden mit |sid98620|id machte"
	psfiretxtopt562 = "|tip2 Wer schaden mit |sid98620|id machte (gesammt)"
	psfiretxtopt563 = "|tip1 Wer keinen schaden bekam (in hero andererseits) von |sid100214|id (außgeschlossen leute die 7 sek |sid100215|id hatten)"
	psfiretxtopt564 = "|tip1 Wer keinen schaden bekam (in hero andererseits) von |sid100214|id (außgeschlossen leute die 7 sek |sid100215|id hatten) - gesamt"
	psfiretxtopt565 = "|tip2 Gesammte Laufzeit von |sid98245|id"
	psfiretxtopt571 = "|tip1 Wer |sid98164|id auslößte wenn jemand davon starb (|cffff0000range check: nicht 100% genau|r)"
	psfiretxtopt5712 = "|tip1 Berichte schadensanteile von |sid100115|id"
	psfiretxtopt5713 = "|tip2 Berichte schadensanteile von |sid100115|id (gesammt)"
	psfiretxtopt572 = "|tip1 Gesammt schaden auf 'Live Meteors' wenn mehr als 250k (könnte übermaß an schaden sein)" -- Needs review
	psfiretxtopt573 = "|tip1 Nach |sid100259|id zeige wer schaden und Stuns auf die Adds machte"
	psfiretxtopt574 = "|tip2 |sid101233|id - wer schaden bekam als sie erschinen ist (nicht weggerannt)"
	psfiretxtoptt533 = "|s4id100359|id bekam NICHT ein Spieler! Buff an"
	psfiretxtoptt544 = "|s4id99947|id wurde unterbrochen von"
	psfiretxtopttmaj = "Gesamte zeit von |s4id98245|id (sek)"
	psfirewhodied = "wer starb info"
	psfirewith = "mit"
	psfireyard = "yard"

end


end

==> go.php?file=PhoenixStyle1.603.zip: PhoenixStyleMod_Firelands/Localization/localization-deDE.lua <==
﻿if GetLocale() == "deDE" then


function psfirellocale()

	psfirebabah = "explodierte"
	psfirebabah2 = "Eigenbeschuss mit |s4id98620,100215,100216,100217|id an Spielern"
	psfirebaleroccrystal = "Kristall"
	psfireby = "von"
	psfireconsumeadd = "Aschenweberdrohne bekam |sid100634|id"
	psfiredamshared = "explosion geteilt zwischen"
	psfiredeadrag = "GESTORBEN"
	psfirediddamageto = "Machte schaden auf"
	psfirediedfrom = "starb von"
	psfireended = "beendet"
	psfirefixate1 = "letzte erledigt vor %s  sek"
	psfirehealedhimself = "geheilt"
	psfireintershanox = "Unterbrochen von"
	psfirekilledplayer = "tötete Spieler!"
	psfirekilledplayers = "tötete %s Spieler!"
	psfireldamagefrom = "Schaden von"
	psfirelgot = "bekam"
	psfirelgotinf = "bekamen"
	psfirelgotinm = "bekamen"
	psfirelgotm = "bekam"
	psfirellastmoduleloadtxt = "Feuerlande"
	psfireltotal = "gesamt"
	psfirelwhogot = "Bekamen"
	psfiremajodamag1 = "Jeder bekam schaden!"
	psfiremajodamag2 = "|s4id98474,100212,100213,100214|id kein schaden auf"
	psfiremajodamag3 = "kein schaden auf"
	psfiremajogotdmg1 = "|s4id98474,100212,100213,100214|id bekamen schaden"
	psfiremajogotdmg2 = "Nur eine Person bekam schaden"
	psfiremajogotdmg3 = "bekamen schaden"
	psfiremaybeexcessd = "möglicher übermaß an schaden auf"
	psfireno = "NEIN"
	psfirenofistsec2 = "nicht die ersten 2 sek"
	psfirenotsure = "nicht sicher"
	psfireragnaknock1 = "Übermaß an Schaden. AddOn konnte nicht herrausfinden wer näher als 6 yards war"
	psfireragnaknock2 = "bekam %s anstatt von"
	psfireragnaknock3 = "Näher als 6 yards"
	psfireshanaddopt1 = "AoE vom Speer"
	psfireshanaddopt2 = "schaden vom Speer"
	psfireshanaddopt3 = "übermaß"
	psfirestaks = "Stapel"
	psfiretauntseff = "erfolgreiche spots auf Aschenweberspinner"
	psfiretauntseff2 = "Spots auf Aschenweberspinner"
	psfiretimes = "mal"
	psfiretrapragna1 = "Zu nahe Spieler (bis zu 8 yards):"
	psfiretrapragna2 = "Niemand wurde im umkreis von  8 yards gefunden"
	psfiretxtopt512 = "|tip2 Wie viele Heilung der Boss von |sid99332|id erhielt"
	psfiretxtopt515 = "|tip1 Wenn jemand anders schaden von |sid99463|id bekommt - zeige wer das Add getankt hat usw. (|cffff0000hero|r)"
	psfiretxtopt516 = "|tip1 Wenn mehr als einer schaden von |sid99990|id bekommt - zeige Chatinfo (|cffff0000hero|r)"
	psfiretxtopt517 = "|tip2 Wer Spot auf Aschenweberspinner benutzte (mehr info im 'im Kampf info' Modul)"
	psfiretxtopt518 = "|tip2 Wie oft Aschenweberdrohne |sid100634|id bekam"
	psfiretxtopt522 = "|tip2 Wie oft Flüssiges Obsidian |sid99875|id zauberte"
	psfiretxtopt533 = "|tip1 Berichte wenn NICHT ein Spieler |sid100359|id bekam"
	psfiretxtopt544 = "|tip2 Wer |sid99947|id unterbrach indem er schaden aufs Add gemacht hat (gesamt)"
	psfiretxtopt551 = "|tip1 wenn ein Spieler vom Kristall mit |sid99257|id getötet wurde - zeige info (wer es auffrischte - |cffff0000hero|r)"
	psfiretxtopt552 = "|tip1 wenn ein Spieler von |sid99353|id getötet wurde mit |sid99257|id - zeige info (wer es auffrischte - |cffff0000hero|r)"
	psfiretxtopt553 = "|tip1 Zeige wer |sid99516|id hatte wenn eine explosion stattgefunden hat (|cffff0000hero|r)"
	psfiretxtopt561 = "|tip1 Wer schaden mit |sid98620|id machte"
	psfiretxtopt562 = "|tip2 Wer schaden mit |sid98620|id machte (gesammt)"
	psfiretxtopt563 = "|tip1 Wer keinen schaden bekam (in hero andererseits) von |sid98474|id (außgeschlossen leute die 7 sek |sid98620|id hatten)"
	psfiretxtopt564 = "|tip1 Wer keinen schaden bekam (in hero andererseits) von |sid98474|id (außgeschlossen leute die 7 sek |sid98620|id hatten) - gesamt"
	psfiretxtopt565 = "|tip2 Gesammte Laufzeit von |sid98245|id"
	psfiretxtopt571 = "|tip1 Wer |sid98164|id auslößte wenn jemand davon starb (|cffff0000range check: nicht 100% genau|r)"
	psfiretxtopt5712 = "|tip1 Berichte schadensanteile von |sid98263|id"
	psfiretxtopt5713 = "|tip2 Berichte schadensanteile von |sid98263|id (gesammt)"
	psfiretxtopt572 = "|tip1 Gesammt schaden auf 'Live Meteors' wenn mehr als 250k (könnte übermaß an schaden sein)"
	psfiretxtopt573 = "|tip1 Nach |sid100259|id zeige wer schaden und Stuns auf die Adds machte"
	psfiretxtopt574 = "|tip2 |sid98170|id - wer schaden bekam als sie erschinen ist (nicht weggerannt)"
	psfiretxtoptt533 = "|s4id100359|id bekam NICHT ein Spieler! Buff an"
	psfiretxtoptt544 = "|s4id99947|id wurde unterbrochen von"
	psfiretxtopttmaj = "Gesamte zeit von |s4id98245|id (sek)"
	psfirewhodied = "wer starb info"
	psfirewith = "mit"
	psfireyard = "yard"


end


end
